Learn R Programming

sknifedatar (version 0.1.2)

automagic_tabs2: Automatic Generation of Tabs with multiple outputs

Description

It allows to automatically generate the code necessary to group multiple Rmarkdown chunks into tabs. Concatenating all the chunks into a string that can be later knitted and rendered.

Usage

automagic_tabs2(
  input_data,
  panel_name,
  ...,
  tabset_title = "",
  tabset_props = ".tabset-fade .tabset-pills",
  chunk_props = list(echo = FALSE, fig.align = "center"),
  is_output_distill = TRUE
)

Arguments

input_data

Ungrouped tibble with at least 2 columns, one for the title of the tabs and another with the output to be displayed.

panel_name

column with the ID variable.

...

nested columns that contain outputs to display.

tabset_title

string title of the .tabset

tabset_props

string defining .tabset properties. Only works with is_output_distill = F

chunk_props

named list with additional parameters that correspond to all those available in rmarkdown chunks (fig.align, fig.width, ...).

is_output_distill

boolean. is output a distill article.

Value

concatenated string of all automatically generated chunks.

Details

given a tiblle, which must contain an "ID" column (representing the title of the tabs) and other columns that stores output to be generated (plot, text, code, ...), a string is automatically generated which can be later rendered in a Rmarkdown document.

See Also

sknifedatar website

Examples

Run this code
# NOT RUN {
library(dplyr)
library(sknifedatar)
library(ggplot2)

dataset <- iris %>% 
  group_by(Species) %>% 
  tidyr::nest() %>% 
  mutate(
    .plot = purrr::map(data, ~ ggplot(.x, aes(x = Sepal.Length, y = Petal.Length)) + geom_point()),
    .table = purrr::map(data, ~ summary(.x) %>% knitr::kable())
  ) %>% 
  ungroup()

automagic_tabs2(input_data = dataset, panel_name = Species, .plot, .table)

unlink("figure", recursive = TRUE)
# }

Run the code above in your browser using DataLab