Learn R Programming

sknifedatar (version 0.1.2)

emae_series: Time series of the monthly estimator of Argentine economic activity, grouped by sector

Description

The EMAE is an indicator that reflects the monthly evolution of the economic activity of all the productive sectors nationwide for Argentina, for more details: EMAE indicator. Data was obtained from all the sectoral EMAE series, from January 2004 to October 2020, from Time Series (API) from the Government Open Data Portal.

Usage

emae_series

Arguments

Format

A data frame with 3104 rows and 3 columns, the variable "date" represents the monthly date, "value" the monthly value of the indicator and the sector column indicates the id or economic sector of the series.