Learn R Programming

sknifedatar (version 0.1.2)

intercepcion_calles: Dataset of the intersection of the main streets and avenues of the city of Buenos Aires, Argentina.

Description

Data set that records the date, time slot, type of crime and geolocation of crimes that occurred between 2017 and 2019 The data was obtained from the Openstreetmap using the osmdata package, later they were transformed until obtaining the tabular structure that is presented here.

Usage

intercepcion_calles

Arguments

Format

A data frame with 2417 rows y 3 columns:

id

corner id

lat

latitude

long

longitude

...