Learn R Programming

sknifedatar (version 0.1.2)

modeltime_multiforecast: Forecasting of multiple models over multiple time series

Description

allows forecasting on multiple time series from multiple fitted models.

Usage

modeltime_multiforecast(models_table, .h = NULL, .prop = NULL)

Arguments

models_table

'table_time' tibble generated with the modeltime_multifit() function.

.h

prediction horizon of the modeltime_forecast() function.

.prop

time series split partition ratio. If "h" is specified, this function predicts on the testing partition.

Value

'models_table' tibble with a new column called 'nested_forecast' where the predictions are stored.

Details

this function takes the 'table_time' object generated with the modeltime_multifit() function, the modeltime_forecast() from the package 'modeltime' is applied to each model for each series.

Examples

Run this code
# NOT RUN {
# Data
data_serie <- sknifedatar::table_time
                                     
# Forecast
sknifedatar::modeltime_multiforecast(data_serie$table_time, .prop=0.8)

# }

Run the code above in your browser using DataLab