powered by
Data corresponds to Vehicle flow through Avellaneda toll in Ciudad Autonoma de Buenos Aires.. From January 2009 to December 2020.
data_avellaneda
A dataframe with 4383 rows y 2 columns: date is the daily date, value is the number of vehicles no that day.