Learn R Programming

sknifedatar (version 0.1.2)

modeltime_multirefit: Refit the model or models for multiple time series

Description

applies the modeltime_refit() function from the 'modeltime' package to multiple series and models.

Usage

modeltime_multirefit(models_table)

Arguments

models_table

'table_time' tibble generated from the modeltime_multifit() function.

Value

retrained 'table_time' object.

Details

it takes the 'table_time' tibble generated with the modeltime_multifit() function and returns the same object but with the models fitted for the complete period.

Examples

Run this code
# NOT RUN {
# Data
library(modeltime)
data_serie <- head(sknifedatar::table_time$table_time,1)
# modeltime_multirefit
sknifedatar::modeltime_multirefit(models_table = data_serie)

# }

Run the code above in your browser using DataLab