modeltime_multirefit: Refit the model or models for multiple time series
Description
applies the modeltime_refit() function from the 'modeltime' package to multiple series and models.
Usage
modeltime_multirefit(models_table)
Arguments
models_table
'table_time' tibble generated from the modeltime_multifit() function.
Value
retrained 'table_time' object.
Details
it takes the 'table_time' tibble generated with the modeltime_multifit() function and
returns the same object but with the models fitted for the complete period.